from django.apps import AppConfig


class Config(AppConfig):
    """Config."""

    name = "invitations"
    label = "invitations"
